@@ -7,6 +7,8 @@ import os
 import csv
 import logging
 from pathlib import Path
+import yaml
+
 
 # import pymongo
 
@@ -37,12 +39,29 @@ def read_json(path):
         d = json.load(f)
     return d
 
+def read_yaml(path):
+    d = []
+    with open(path, encoding="utf-8") as f:
+        doc = yaml.load(f, Loader=yaml.FullLoader)
+    return doc
+
+def read_yamls(path):
+    d = []
+    with open(path, encoding="utf-8") as f:
+        docs = yaml.load_all(f, Loader=yaml.FullLoader)
+    return docs
+
 def read_file(path):
     d = []
     with open(path, encoding="utf-8") as f:
         d = f.read()
     return d
 
+def write_yaml(path, data):
+    with open(path, 'w', encoding="utf-8") as file:
+        yaml.dump(data, file)
+    return True
+
 def write_json(path, data):
     with open(path, 'w', encoding="utf-8") as file:
         json.dump(data, file, ensure_ascii=False)
